@@ -23,7 +23,7 @@ require Exporter;
 
 @EXPORT = qw();
 
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 # Preloaded methods go here.
 # -----------------------------------------------------------------
@@ -610,16 +610,14 @@ sub startHandlerPhase1
 				! defined($attribute{'tocEntry'}) );
 
 		croak("Each form entity must have a unique 'formFileName' attribute\n")
-			if (defined($attribute{'formFileName'}) &&
-				defined($formFileNameSeen{$attribute{'formFileName'} }) );
+			if (defined($formFileNameSeen{$attribute{'formFileName'} }) );
 
 		croak("Each form entity must have a unique 'heading' attribute\n")
 			if (defined($formHeadingSeen{$attribute{'heading'} }) );
 
 		$formCountPhase1++;
 
-		$formFileNameSeen{$attribute{'formFileName'} }	= $formCountPhase1
-			if (defined($attribute{'formFileName'}) );
+		$formFileNameSeen{$attribute{'formFileName'} }	= $formCountPhase1;
 		$formHeadingSeen{$attribute{'heading'} }		= $formCountPhase1;
 
 		push(@tableOfContents, $attribute{'tocEntry'});
@@ -833,18 +831,18 @@ Keys and values recognized are:
 
 =item *
 
-	'debug' => '1' means turn on debugging. At the moment this opens and closes the
-	file CGI-Formalware.log, but does not write anything to it
+'debug' => '1' means turn on debugging. At the moment this opens and closes the
+file CGI-Formalware.log, but does not write anything to it
 
 =item *
 
-	'form2file' => '1' means output each form to a file, using the name given
-	by the form's formFileName attribute. The forms are written to cgi-bin/.
-	If the form has no such attribute, this option is ignored. See example below
+'form2file' => '1' means output each form to a file, using the name given
+by the form's formFileName attribute. The forms are written to cgi-bin/.
+If the form has no such attribute, this option is ignored. See example below
 
 =item *
 
-	'timeScripts' => '1' means report elapsed time at the end of each script's output
+'timeScripts' => '1' means report elapsed time at the end of each script's output
 
 =back
 
@@ -921,10 +919,6 @@ The password values are zapped by CGI.pm, not by me. This is a security feature.
 It means you can walk away from your system and not have someone gain automatic
 access to a remote system.
 
-=head1 FORM FORMAT
-
-Very simple.
-
 =head1 CASCADING STYLE SHEETS
 
 Each form entity may have a 'css' attribute, giving the name of the CSS file for
@@ -932,7 +926,7 @@ that form. These attribute values are like '/CGI-Formalware.css', which, under
 Apache, means this value is prefixed with DocumentRoot. That is, the path to the
 CSS is a URI, and will not be seen if in cgi-bin/.
 
-The compulsory elements are: H1, H2 and TOC.
+The compulsory elements are: H1, H2 and P.TOC.
 
 Herewith a sample:
 
@@ -957,10 +951,6 @@ Herewith a sample:
 		background-color:	blue;
 	}
 
-=head1 COMMAND LINE OPTIONS
-
-None.
-
 =head1 ENVIRONMENT VARIABLES
 
 None.
@@ -1175,10 +1165,6 @@ Net::Telnet
 
 XML::DOM
 
-=item *
-
-projectLib.pl (from my web site)
-
 =back
 
 =head1 AUTHOR
